@@ -1,7 +1,7 @@
-# WordNet::Similarity::vector.pm version 0.10
-# (Last updated $Id: vector.pm,v 1.10 2004/10/23 07:23:05 sidz1979 Exp $)
+# WordNet::Similarity::vector.pm version 0.14
+# (Last updated $Id: vector.pm,v 1.17 2005/06/08 17:11:11 sidz1979 Exp $)
 #
-# Module to accept two WordNet synsets and to return a floating point
+# Module accepts two WordNet synsets and returns a floating point
 # number that indicates how similar those two synsets are, using a
 # gloss vector overlap measure based on "context vectors" described by
 # Schütze (1998).
@@ -50,17 +50,19 @@ use get_wn_info;
 use stem;
 use vectorFile;
 use WordNet::Similarity;
+use File::Spec;
 use vars qw($VERSION @ISA);
 
 @ISA = qw(WordNet::Similarity);
 
-$VERSION = '0.10';
+$VERSION = '0.14';
 
 WordNet::Similarity::addConfigOption("relation", 0, "p", undef);
-WordNet::Similarity::addConfigOption("vectordb", 1, "p", undef);
+WordNet::Similarity::addConfigOption("vectordb", 0, "p", undef);
 WordNet::Similarity::addConfigOption("stop", 0, "p", undef);
 WordNet::Similarity::addConfigOption("stem", 0, "i", 0);
 WordNet::Similarity::addConfigOption("compounds", 0, "p", undef);
+WordNet::Similarity::addConfigOption("textsize", 0, "i", "-1");
 
 sub setPosList
 {
@@ -168,14 +170,50 @@ sub initialize
     }
 
     # Initialize the word vector database interface...
-    if(!defined $self->{vectordb})
+    if(!defined $self->{vectordb} || $self->{vectordb} eq "")
+    {	
+        my $path;
+        my $header;
+        my @possiblePaths = ();
+        $vectorDB = "";
+
+        # Look for all possible default data files installed.
+        foreach $path (@INC) 
+        {
+            # JM 1-16-04  -- modified to use File::Spec
+            my $file = File::Spec->catfile($path, 'WordNet', 'wordvectors.dat');
+            push @possiblePaths, $file if(-e $file);
+        }
+        
+        # If there are multiple possibilities, get the one in the correct format.
+        foreach $path (@possiblePaths) 
+        {
+            next if(!open(VECTORS, $path));
+            $header = <VECTORS>;
+            $header =~ s/\s+//g;
+            if($header =~ /DOCUMENTCOUNT/)
+            {
+                $vectorDB = $path;
+                $self->{vectordb} = $path;
+                close(VECTORS);
+                last;
+            }
+            close(VECTORS);
+        }
+    }
+    else
+    {
+        $vectorDB = $self->{vectordb};
+    }
+
+    # Initialize the word vector database interface...
+    if(!defined $vectorDB || $vectorDB eq "")
     {	
 	$self->{errorString} .= "\nError (WordNet::Similarity::vector->initialize()) - ";
-	$self->{errorString} .= "Word Vector database file not specified. Use configuration file.";
+	$self->{errorString} .= "No usable Word Vector database found. Use configuration file.";
 	$self->{error} = 2;
 	return;
     }
-    $vectorDB = $self->{vectordb};
 
     # Get the documentCount, dimensions and vectors...
     ($documentCount, $readDims, $readVectors) = vectorFile->readVectors($vectorDB);
@@ -209,7 +247,36 @@ sub initialize
     }
 
     # If relation file not specified... manually add the relations to
-    # be used...
+    # be used... Look for the default vector relation file...
+    if(!defined $self->{relation}) 
+    {
+        my $path;
+        my $header;
+        my @possiblePaths = ();
+        
+        # Look for all possible default data files installed.
+        foreach $path (@INC) 
+        {
+            # JM 1-16-04  -- modified to use File::Spec
+            my $file = File::Spec->catfile($path, 'WordNet', 'vector-relation.dat');
+            push @possiblePaths, $file if(-e $file);
+        }
+        
+        # If there are multiple possibilities, get the one in the correct format.
+        foreach $path (@possiblePaths) 
+        {
+            next if(!open(RELATIONS, $path));
+            $header = <RELATIONS>;
+            $header =~ s/\s+//g;
+            if($header =~ /VectorRelationFile/)
+            {
+                $self->{relation} = $path;
+                close(RELATIONS);
+                last;
+            }
+            close(RELATIONS);
+        }
+    }
     if(!(defined $self->{relation}))
     {
 	$self->{weights}->[0] = 1;
@@ -339,8 +406,9 @@ sub initialize
 	    return;
 	}
     }
-}
 
+    $self->{textsize} = -1 if(!defined $self->{textsize});
+}
 
 # show all config options specific to this module
 sub traceOptions {
@@ -350,6 +418,7 @@ sub traceOptions {
   $self->{traceString} .= "compounds File :: ".((defined $self->{compounds})?"$self->{compounds}":"")."\n";
   $self->{traceString} .= "stop File :: ".((defined $self->{stop})?"$self->{stop}":"")."\n";
   $self->{traceString} .= "stem :: $self->{stem}\n";
+  $self->{traceString} .= "textsize :: $self->{textsize}\n";
 }
 
 =item $vector->getRelatedness
@@ -545,6 +614,7 @@ sub getRelatedness
 	# ah so we do need SOME traces! put in the synset names.
 	$self->{traceString} .= "Synset 1: $wps1";
     }
+    $sizea = 0;
     if(defined $self->{vCache}->{$wps1})
     {
 	$a = $self->{vCache}->{$wps1};
@@ -552,7 +622,7 @@ sub getRelatedness
     }
     else
     {
-	($a, $trr, $maga) = $self->_getVector($firstString);
+	($a, $trr, $maga, $sizea) = $self->_getVector($firstString);
 	$self->{traceString} .= "\nString: \"$firstString\"\n$trr\n" if($self->{trace});
 	&_norm($a, $maga);
 	$self->{vCache}->{$wps1} = $a;
@@ -569,6 +639,7 @@ sub getRelatedness
 	# ah so we do need SOME traces! put in the synset names.
 	$self->{traceString} .= "Synset 2: $wps2";
     }
+    $sizeb = 0;
     if(defined $self->{vCache}->{$wps2})
     {
 	$b = $self->{vCache}->{$wps2};
@@ -576,7 +647,7 @@ sub getRelatedness
     }
     else
     {
-	($b, $trr, $magb) = $self->_getVector($secondString);
+	($b, $trr, $magb, $sizeb) = $self->_getVector($secondString);
 	$self->{traceString} .= "\nString: \"$secondString\"\n$trr\n" if($self->{trace});
 	&_norm($b, $magb);
 	$self->{vCache}->{$wps2} = $b;
@@ -604,7 +675,7 @@ sub _getVector
     my $self = shift;
     my $text = shift;
     my $ret = {};
-    return $ret if(!defined $text);
+    return ($ret, "", 0, 0) if(!defined $text);
     my @words = split(/\s+/, $text);
     my $word;
     my %types;
@@ -612,6 +683,7 @@ sub _getVector
     my $localTraces = "";
     my $kk;
     my $mag;
+    my $count = 0;
 
     # [trace]
     if($self->{trace})
@@ -622,7 +694,12 @@ sub _getVector
 
     foreach $word (@words)
     {
-	$types{$word} = 1 if($word !~ /[XGES]{3}\d{5}[XGES]{3}/);
+        if($word !~ /[XGES]{3}\d{5}[XGES]{3}/)
+        {
+            $types{$word} = 1;
+            $count++;
+            last if($self->{textsize} >= 0 && $count > $self->{textsize});  
+        }
     }
     foreach $word (keys %types)
     {
@@ -652,7 +729,7 @@ sub _getVector
 	$mag += ($ret->{$kk} * $ret->{$kk});
     }
 
-    return ($ret, $localTraces, sqrt($mag));
+    return ($ret, $localTraces, sqrt($mag), $count);
 }
 
 # Normalizes the sparse vector.
@@ -731,7 +808,7 @@ sub _compoundify
 
     while($firstPointer <= $#wordsArray)
     {
-	$secondPointer = $#wordsArray;
+	$secondPointer = (($firstPointer + 5 < $#wordsArray)?($firstPointer + 5):($#wordsArray));
 	$done = 0;
 	while($secondPointer > $firstPointer && !$done)
 	{
